@@ -10,9 +10,9 @@ class Args(object):
     pass
 
 args = Args()
-args.sjds = [59730]
-args.exps = [[41680010, 41680011, 41680012, 41680013, 41680014, 41680015,
-              41680016, 41680017, 41680018]]
+args.sjds = [59801]
+args.exps = [[42390012, 42390013, 42390014, 42390033, 42390034, 42390035,
+              42390036]]
 args.plot = False
 args.verbose = True
 
